@@ -35,38 +35,59 @@ class Assets(WMLResource):
         self._ICP = client.ICP
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
-    def get_details(self, asset_uid):
+    def get_details(self, asset_uid=None):
         """
-            Get data asset details.
+            Get data asset details. If no asset_uid is passed, details for all assets will be returned.
 
             **Parameters**
 
-            .. important::
-                #. **asset_details**:  Metadata of the stored data asset\n
-                   **type**: dict\n
-
-            **Output**
-
             .. important::
                 **returns**: Unique id  of asset\n
                 **return type**: str
 
+            **Output**
+
+            .. important::
+                #. **asset_details**:  Metadata of the stored data asset\n
+                   **type**: dict\n
+
             **Example**
 
              >>> asset_details = client.data_assets.get_details(asset_uid)
         """
-        Assets._validate_type(asset_uid, u'asset_uid', STR_TYPE, True)
+        Assets._validate_type(asset_uid, u'asset_uid', STR_TYPE, False)
+
+        if asset_uid:
+            if not self._ICP and not self._client.WSD:
+                response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid), params=self._client._params(),
+                                        headers=self._client._get_headers())
+            else:
+                response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid), params=self._client._params(),
+                                          headers=self._client._get_headers(), verify=False)
 
-        if not self._ICP and not self._client.WSD:
-            response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid), params=self._client._params(),
-                                    headers=self._client._get_headers())
-        else:
-            response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid), params=self._client._params(),
-                                      headers=self._client._get_headers(), verify=False)
-        if response.status_code == 200:
             return self._get_required_element_from_response(self._handle_response(200, u'get asset details', response))
+
         else:
-            return self._handle_response(200, u'get asset details', response)
+            href = self._client.service_instance._href_definitions.get_search_asset_href()
+
+            data = {
+                "query": "*:*"
+            }
+
+            if not self._ICP and not self._client.WSD:
+                response = requests.post(href,
+                                        json=data,
+                                        params=self._client._params(),
+                                        headers=self._client._get_headers())
+            else:
+                response = requests.post(href,
+                                        json=data,
+                                        params=self._client._params(),
+                                        headers=self._client._get_headers(), verify=False)
+
+            return {'resources': [
+                self._get_required_element_from_response(x)
+                for x in self._handle_response(200, u'get assets details', response)['results']]}
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def create(self, name, file_path):
@@ -654,44 +675,26 @@ class Assets(WMLResource):
     def _get_required_element_from_response(self, response_data):
 
         WMLResource._validate_type(response_data, u'data assets response', dict)
+
+        import copy
+        new_el = {'metadata': copy.copy(response_data['metadata'])}
+
         try:
+            new_el['metadata']['guid'] = response_data['metadata']['asset_id']
+            new_el['metadata']['href'] = response_data['href'] if not (self._client.WSD and self._client.default_project_id) else self._client.service_instance._href_definitions.get_base_asset_href(response_data['metadata']['asset_id']) + "?" + "project_id=" + response_data['metadata']['project_id']
+
+            new_el['metadata']['asset_type'] = response_data['metadata']['asset_type']
+            new_el['metadata']['created_at'] = response_data['metadata']['created_at']
+            new_el['metadata']['last_updated_at'] = response_data['metadata']['usage'].get('last_updated_at')
+
             if self._client.default_space_id is not None:
-                new_el = {'metadata': {'space_id': response_data['metadata']['space_id'],
-                                       'guid': response_data['metadata']['asset_id'],
-                                       'href': response_data['href'],
-                                       'asset_type': response_data['metadata']['asset_type'],
-                                       'created_at': response_data['metadata']['created_at'],
-                                       'last_updated_at': response_data['metadata']['usage'].get('last_updated_at')
-                                       },
-                          'entity': response_data['entity']
+                new_el['metadata']['space_id'] = response_data['metadata']['space_id']
 
-                          }
             elif self._client.default_project_id is not None:
-                if self._client.WSD:
+                new_el['metadata']['project_id'] = response_data['metadata']['project_id']
 
-                    href = self._client.service_instance._href_definitions.get_base_asset_href(response_data['metadata']['asset_id']) + "?" + "project_id=" + response_data['metadata']['project_id']
-
-                    new_el = {'metadata': {'project_id': response_data['metadata']['project_id'],
-                                           'guid': response_data['metadata']['asset_id'],
-                                           'href': href,
-                                           'asset_type': response_data['metadata']['asset_type'],
-                                           'created_at': response_data['metadata']['created_at'],
-                                           'last_updated_at': response_data['metadata']['usage'].get('last_updated_at')
-                                           },
-                              'entity': response_data['entity']
-
-                              }
-                else:
-                    new_el = {'metadata': {'project_id': response_data['metadata']['project_id'],
-                                       'guid': response_data['metadata']['asset_id'],
-                                       'href': response_data['href'],
-                                       'asset_type': response_data['metadata']['asset_type'],
-                                       'created_at': response_data['metadata']['created_at'],
-                                       'last_updated_at': response_data['metadata']['usage'].get('last_updated_at')
-                                       },
-                             'entity': response_data['entity']
-
-                            }
+            if 'entity' in response_data:
+                new_el['entity'] = response_data['entity']
 
             if self._client.ICP_30 is not None or self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
                 if "attachments" in response_data and response_data[u'attachments']:
