@@ -105,9 +105,9 @@ class Connections(WMLResource):
             raise WMLClientError("Failed to read Response from down-stream service: " + response_data)
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
-    def get_details(self, connection_id):
+    def get_details(self, connection_id=None):
         """
-        Get connection details for the given unique Connection id.
+        Get connection details for the given unique Connection id. If no connection_id is passed, details for all connections will be returned.
 
         **Parameters**
 
@@ -124,25 +124,36 @@ class Connections(WMLResource):
         **Example**
 
          >>> connection_details = client.connections.get_details(connection_id)
+         >>> connection_details = client.connections.get_details()
         """
         self._client._check_if_either_is_set()
-        Connections._validate_type(connection_id, u'connection_id', STR_TYPE, True)
+        Connections._validate_type(connection_id, u'connection_id', STR_TYPE, False)
 
         if self._client.WSD:
             header_param = self._client._get_headers(wsdconnection_api_req=True)
         else:
             header_param = self._client._get_headers()
 
-        if not self._client.ICP_30 and not self._client.ICP and not self._client.WSD:
-            response = requests.get(self._href_definitions.get_connection_by_id_href(connection_id), params=self._client._params(),
-                                    headers=header_param)
+        verify = not self._client.ICP_30 and not self._client.ICP and not self._client.WSD
+        if connection_id:
+            response = requests.get(self._client.service_instance._href_definitions.get_connection_by_id_href(connection_id),
+                                    params=self._client._params(),
+                                    headers=header_param, verify=verify)
+
+            if response.status_code == 200:
+                return self._get_required_element_from_response(
+                    self._handle_response(200, u'get connection details', response))
+            else:
+                return self._handle_response(200, u'get connection details', response)
         else:
-            response = requests.get(self._href_definitions.get_connection_by_id_href(connection_id), params=self._client._params(),
-                                    headers=header_param, verify=False)
-        if response.status_code == 200:
-            return self._get_required_element_from_response(self._handle_response(200, u'get connection details', response))
-        else:
-            return self._handle_response(200, u'get connection details', response)
+            response = requests.get(self._client.service_instance._href_definitions.get_connections_href(),
+                                    params=self._client._params(),
+                                    headers=header_param, verify=verify)
+
+            if response.status_code == 200:
+                return {'resources': [self._get_required_element_from_response(x) for x in response.json()['resources']]}
+            else:
+                return self._handle_response(200, u'get connection details', response)
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def create(self, meta_props):
@@ -265,14 +276,14 @@ class Connections(WMLResource):
 
         if not self._client.ICP_30 and not self._client.ICP and not self._client.WSD:
             creation_response = requests.post(
-                    self._href_definitions.get_connections_href(),
+                    self._client.service_instance._href_definitions.get_connections_href(),
                     headers=header_param,
                     params = self._client._params(),
                     json=connection_meta
             )
         else:
             creation_response = requests.post(
-                self._href_definitions.get_connections_href(),
+                self._client.service_instance._href_definitions.get_connections_href(),
                 headers=header_param,
                 json=connection_meta,
                 params=self._client._params(),
@@ -318,7 +329,7 @@ class Connections(WMLResource):
         else:
             header_param = self._client._get_headers()
 
-        connection_endpoint = self._href_definitions.get_connection_by_id_href(connection_id)
+        connection_endpoint = self._client.service_instance._href_definitions.get_connection_by_id_href(connection_id)
         if not self._ICP and not self._client.ICP_30 and not self._client.WSD:
             response_delete = requests.delete(connection_endpoint, params=self._client._params(),
                                               headers=header_param)
@@ -381,10 +392,10 @@ class Connections(WMLResource):
             header_param = self._client._get_headers()
 
         if not self._client.ICP_30 and not self._client.ICP and not self._client.WSD:
-            response = requests.get(self._href_definitions.get_connection_data_types_href(),
+            response = requests.get(self._client.service_instance._href_definitions.get_connection_data_types_href(),
                                     headers=header_param)
         else:
-            response = requests.get(self._href_definitions.get_connection_data_types_href(),
+            response = requests.get(self._client.service_instance._href_definitions.get_connection_data_types_href(),
                                     headers=header_param, verify=False)
 
         datasource_details = self._handle_response(200, u'list datasource types', response)['resources']
@@ -415,11 +426,11 @@ class Connections(WMLResource):
             header_param = self._client._get_headers()
 
         if not self._client.ICP_30 and not self._client.ICP and not self._client.WSD:
-            response = requests.get(self._href_definitions.get_connections_href(),
+            response = requests.get(self._client.service_instance._href_definitions.get_connections_href(),
                                     params=self._client._params(),
                                     headers=header_param)
         else:
-            response = requests.get(self._href_definitions.get_connections_href(),
+            response = requests.get(self._client.service_instance._href_definitions.get_connections_href(),
                                     params=self._client._params(),
                                     headers=header_param, verify=False)
 
@@ -462,10 +473,10 @@ class Connections(WMLResource):
             header_param = self._client._get_headers()
 
         if not self._client.ICP_30 and not self._client.ICP and not self._client.WSD:
-            response = requests.get(self._href_definitions.get_connection_data_types_href(),
+            response = requests.get(self._client.service_instance._href_definitions.get_connection_data_types_href(),
                                     headers=header_param)
         else:
-            response = requests.get(self._href_definitions.get_connection_data_types_href(),
+            response = requests.get(self._client.service_instance._href_definitions.get_connection_data_types_href(),
                                     headers=header_param, verify=False)
         datasource_id = 'None'
         datasource_details = self._handle_response(200, u'list datasource types', response)['resources']
