@@ -19,7 +19,7 @@ from typing import TYPE_CHECKING, Any, Dict, Union, List, Optional
 from pandas import DataFrame, concat
 
 from .base_deployment import BaseDeployment
-from ..helpers import DataConnection
+from ..helpers import DataConnection, AssetLocation
 from ..utils import StatusLogger, print_text_header_h1
 from ..utils.autoai.connection import validate_source_data_connections, validate_deployment_output_connection
 from ..utils.autoai.utils import init_cos_client, try_load_dataset
@@ -224,6 +224,12 @@ class Batch(BaseDeployment):
             if isinstance(payload[0], DataConnection):
                 if None in payload:
                     raise NoneDataConnection('payload')
+
+                # wml_client sets correct href for Data Assets
+                for data_conn in payload:
+                    if hasattr(data_conn, 'location') and isinstance(data_conn.location, AssetLocation):
+                        data_conn.location.wml_client = self._target_workspace.wml_client
+
                 payload = [new_conn for conn in payload for new_conn in conn._subdivide_connection()]
                 payload = validate_source_data_connections(source_data_connections=payload,
                                                            workspace=self._target_workspace,
@@ -238,6 +244,11 @@ class Batch(BaseDeployment):
                 raise ValueError("\"output_data_reference\" should be provided.")
 
             if isinstance(output_data_reference, DataConnection):
+
+                # wml_client sets correct href for Data Assets
+                if hasattr(output_data_reference, 'location') and isinstance(output_data_reference.location, AssetLocation):
+                    output_data_reference.location.wml_client = self._target_workspace.wml_client
+
                 output_data_reference = validate_deployment_output_connection(
                     results_data_connection=output_data_reference,
                     workspace=self._target_workspace,
