@@ -15,4 +15,4 @@
 from ibm_watson_machine_learning.helpers.helpers import *
 from ibm_watson_machine_learning.helpers.connections import (
     DataConnection, S3Connection, S3Location, FSLocation, AssetLocation, CP4DAssetLocation, WMLSAssetLocation,
-    WSDAssetLocation, NFSLocation, NFSConnection)
+    WSDAssetLocation, NFSLocation, NFSConnection, ConnectionAsset, ConnectionAssetLocation, DatabaseLocation)
