@@ -378,7 +378,7 @@ class ServiceInstanceNewPlan:
             **returns**: Newly created token if returned if no errors occurred.\n
             **return type**: str\n
         """
-        if self._client.ICP_40 and 'bedrock_url' in self._client.wml_credentials:
+        if self._client.ICP_40 and 'bedrock_url' in self._client.wml_credentials and 'password' in self._client.wml_credentials:
             try:
                 return self._get_cpd_token_from_request_new_auth_flow()
             except Exception as e1:
@@ -392,7 +392,7 @@ class ServiceInstanceNewPlan:
                     return res
                 except Exception as e2:
                     if hasattr(self._client, '_is_bedrock_url_autogenerated') and self._client._is_bedrock_url_autogenerated:
-                        raise CannotAutogenerateBedrockUrl()
+                        raise CannotAutogenerateBedrockUrl(e1, e2)
                     else:
                         raise e2
         else:
