@@ -1,11 +1,11 @@
 import unittest,time
 
-from ibm_watson_machine_learning.utils.log_util import get_logger
+import logging
 from ibm_watson_machine_learning.tests.Cloud.preparation_and_cleaning import *
 
 class TestDataAssets(unittest.TestCase):
 
-    logger = get_logger(__name__)
+    logger = logging.getLogger(__name__)
 
     @classmethod
     def setUpClass(self):
