@@ -1,5 +1,5 @@
 import unittest
-from ibm_watson_machine_learning.utils.log_util import get_logger
+import logging
 from ibm_watson_machine_learning.wml_client_error import ApiRequestFailure
 from ibm_watson_machine_learning.tests.Cloud.preparation_and_cleaning import *
 
@@ -14,7 +14,7 @@ class TestExportImport(unittest.TestCase):
     deployment_id = None
     scoring_url = None
 
-    logger = get_logger(__name__)
+    logger = logging.getLogger(__name__)
 
     @classmethod
     def setUpClass(self):
