@@ -1,5 +1,5 @@
 import unittest
-from ibm_watson_machine_learning.utils.log_util import get_logger
+import logging
 from sklearn import datasets
 from sklearn.pipeline import Pipeline
 from sklearn import preprocessing
@@ -14,7 +14,7 @@ class TestWMLClientWithScikitLearn(unittest.TestCase):
     model_id = None
     scoring_url = None
     space_id = None
-    logger = get_logger(__name__)
+    logger = logging.getLogger(__name__)
 
     @classmethod
     def setUpClass(self):
