@@ -25,12 +25,7 @@ from ibm_watson_machine_learning.utils.autoai.enums import PositiveLabelClass, R
 from ibm_watson_machine_learning.utils.autoai.utils import chose_model_output
 
 
-
-# from lale import wrap_imported_operators
-# from lale.operators import TrainablePipeline
-# from lale.lib.lale import Hyperopt
-
-
+@unittest.skipIf(is_cp4d(), "Excel files not supported on CPD 4.0 an low")
 class TestAutoAIRemote(unittest.TestCase):
     """
     The test covers:
@@ -241,6 +236,9 @@ class TestAutoAIRemote(unittest.TestCase):
         # print(parameters)
         self.assertIsNotNone(parameters)
 
+    def test_06c_get_metrics(self):
+        self.wml_client.training.get_metrics(self.run_id)
+
     def test_07_get_summary(self):
 
         print(f"Run status = {self.remote_auto_pipelines.get_run_status()}")
