@@ -98,9 +98,14 @@ class TestAutoAIRemote(unittest.TestCase):
             del cls.wml_credentials['password']
         except:
             pass
+        try:
+            del cls.wml_credentials['bedrock_url']
+        except:
+            pass
 
         assert(cls.wml_credentials.get('username') is not None)
-        assert(cls.wml_credentials.get('password') is not None)
+        assert(cls.wml_credentials.get('password') is None)
+        assert (cls.wml_credentials.get('bedrock_url') is None)
         assert(cls.wml_credentials.get('apikey') is not None)
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials.copy())
 
@@ -271,6 +276,9 @@ class TestAutoAIRemote(unittest.TestCase):
         print(parameters.get('entity').get('status'))
         self.assertIsNotNone(parameters)
 
+    def test_08b_get_metrics(self):
+        self.wml_client.training.get_metrics(self.run_id)
+
     def test_09_predict_using_fitted_pipeline(self):
         predictions = self.remote_auto_pipelines.predict(X=self.X_values[:5])
         print(predictions)
