@@ -241,6 +241,9 @@ class TestAutoAIRemote(unittest.TestCase):
         # print(parameters)
         self.assertIsNotNone(parameters)
 
+    def test_07b_get_metrics(self):
+        self.wml_client.training.get_metrics(self.run_id)
+
     def test_08_summary_listing_all_pipelines_from_wml(self):
         pipelines_details = self.remote_auto_pipelines.summary()
         print(pipelines_details)
