@@ -479,6 +479,9 @@ class TestOBMOnly(unittest.TestCase):
         print(parameters)
         self.assertIsNotNone(parameters)
 
+    def test_14b_get_metrics(self):
+        self.wml_client.training.get_metrics(self.run_id)
+
     @print_test_separators
     def test_15__get_data_connections__return_a_list_with_data_connections_with_optimizer_params(self):
         print("Getting all data connections...")
