@@ -515,6 +515,9 @@ class TestOBMAndKB(unittest.TestCase):
         print(parameters)
         self.assertIsNotNone(parameters)
 
+    def test_13b_get_metrics(self):
+        self.wml_client.training.get_metrics(self.run_id)
+
     @print_test_separators
     def test_14_predict_using_fitted_pipeline(self):
         print("Make predictions on best pipeline...")
