@@ -178,11 +178,9 @@ class TestAutoAIRemote(unittest.TestCase):
 
     def test_02a_read_saved_remote_data_before_fit(self):
         if self.wml_client.ICP:
-            with self.assertRaises(CannotReadSavedRemoteDataBeforeFit, msg="Should fail with adequate error"):
+            with self.assertRaises(NotImplementedError, msg="Should fail with adequate error"):
                 data = self.data_connection.read()
 
-            with self.assertRaises(CannotReadSavedRemoteDataBeforeFit, msg="Should fail with adequate error"):
-                data = self.data_connection.read()
         else:
             data = self.data_connection.read()
             print(f"Data sample")
@@ -247,6 +245,9 @@ class TestAutoAIRemote(unittest.TestCase):
         # print(parameters)
         self.assertIsNotNone(parameters)
 
+    def test_08b_get_metrics(self):
+        self.wml_client.training.get_metrics(self.run_id)
+
     def test_09_predict_using_fitted_pipeline(self):
         predictions = self.remote_auto_pipelines.predict(X=self.X_values[:5])
         print(predictions)
