@@ -1026,20 +1026,15 @@ class Training(WMLResource):
 
         training_uid = str_type_conv(training_uid)
         Training._validate_type(training_uid, u'training_uid', STR_TYPE, True)
-        if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
-            entity = self.get_details(training_uid)
-            if 'metrics' in entity:
-                metrics = entity['metrics']
-                return metrics
-            else:
-                raise WMLClientError(" There is no Metrics details are available for the given training_uid")
+        status = self.get_status(training_uid)
+        if 'metrics' in status:
+            return status['metrics']
         else:
-            status = self.get_status(training_uid)
-            if 'metrics' in status:
-                metrics = status['metrics']
-                return metrics
+            details = self.get_details(training_uid)
+            if 'metrics' in details:
+                return details['metrics']
             else:
-                raise WMLClientError(" There is no Metrics details are available for the given training_uid")
+                raise WMLClientError("No metrics details are available for the given training_uid")
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def _get_latest_metrics(self, training_uid):
