@@ -499,6 +499,7 @@ def prepare_auto_ai_model_to_publish_notebook_normal_scenario(
     request_json: Dict[str, dict] = json.loads(request_str)
     if 'connection' in run_params['entity']['results_reference']:
         request_json['content_location']['connection'] = run_params['entity']['results_reference']['connection']
+
     request_json = preprocess_request_json(request_json, space_id)
     artifact_name = f"autoai_sdk{os.path.sep}{pipeline_model}.pickle"
 
@@ -629,7 +630,8 @@ def prepare_auto_ai_model_to_publish_normal_scenario(
     if 'connection' in run_params['entity']['results_reference']:
         request_json['content_location']['connection'] = run_params['entity']['results_reference']['connection']
     # note: if training was on project_id, change it to space_id as we can deploy only on space
-    request_json = preprocess_request_json(request_json, space_id)
+    if not wml_client.ICP_40:
+        request_json = preprocess_request_json(request_json, space_id)
     artifact_name = f"autoai_sdk{os.path.sep}{pipeline_model}.pickle"
 
     return artifact_name, request_json
@@ -1066,6 +1068,12 @@ def check_dependencies_versions(request_json: dict, wml_client, estimator_pkg: s
                 # workaround for autai-libs and numpy versions in SW spec
                 if package['name'] == 'autoai-libs' or package['name'] == 'numpy' or package['name'] == 'lale':
                     if version.parse(installed_module_version) < version.parse(package['version']):
+                        # we should produce different error for lale as only 2 major numbers are significant
+                        if package['name'] == 'lale' and len(package['version'].split('.')) == 3:
+                            _version = package['version'].split('.')
+                            _version[-1] = 'x'
+                            package['version'] = '.'.join(_version)
+
                         errored_packages.append(package)
 
                 else:
