@@ -10,6 +10,8 @@ irrespective of what has been deposited with the U.S. Copyright Office.
 client combo
 """
 import logging
+import socket
+
 import requests
 import asyncio
 import signal
@@ -97,7 +99,7 @@ class WSConnection(FLConnection):
             # set a default value to be aggregator
             self.wsrecvport = "/aggregator1"
 
-        
+
     async def PartySendLoop(self):
         """
         This is started at the party.
@@ -117,7 +119,7 @@ class WSConnection(FLConnection):
             if len(party_sbuffer) == 0:
                 logger.info("PartySendLoop: Holding for message to send" )
                 pSendEvt.wait()
-            try:   
+            try:
                 logger.info("PartySendLoop: Number of active messages ready to send: " + str(len(party_sbuffer)))
                 msg = party_sbuffer.popleft()
             except IndexError:
@@ -130,7 +132,7 @@ class WSConnection(FLConnection):
                 headers = { 'Authorization': self.authToken, 'rtsid': self.party }
             try:
                 async with websockets.connect(uri, max_size=2 ** 29, read_limit=2 ** 29, write_limit=2**29, ssl=ssl_context_party, extra_headers=headers) as websocket:
-                    
+
                     if self.flagForOutstandingMessageResponseToBeReceived == False:
                         logger.debug(
                             "PartySendLoop: Attempting to send message to aggregator")
@@ -149,7 +151,7 @@ class WSConnection(FLConnection):
                     self.flagForOutstandingMessageResponseToBeReceived = False
                     party_rbuffer.append(resp)
                     pRecvEvt.set()
-                    
+
             except websockets.exceptions.ConnectionClosedError as ex:
                 if self.stopped != True:
                     logger.error(
@@ -166,6 +168,9 @@ class WSConnection(FLConnection):
                 logger.error(
                     "PartySendLoop : WebsocketException. Details: " + str(ex))
                 return False
+            except socket.gaierror as ex:
+                logger.error("PartySendLoop : Error connecting to " + uri + ". Exception is " + str(ex))
+                return False
             except Exception as ex:
                 logger.error("PartySendLoop : Exception is " + str(ex))
                 return False
@@ -206,11 +211,11 @@ class WSConnection(FLConnection):
                         request_path = str(recv_msg.message_type)
                         logger.debug(
                             "REQUEST PATH IN PARTY IS " + str(request_path))
-                        
+
                         # check if error
                         if recv_msg.message_type == MessageType.ERROR_AUTH.value :
                             logger.info(
-                            "PartyRecvLoop : Received AUTH ERROR message" )
+                            "PartyRecvLoop : Auth Error. Please verify training ID, RTS, project permission and token")
                             self.stop()
                             break;
 
@@ -238,7 +243,7 @@ class WSConnection(FLConnection):
                             "PartyRecvLoop : Received STOP message" )
                             self.stop()
                             break;
-                        
+
             except websockets.exceptions.ConnectionClosedError as ex:
                 if self.stopped != True:
                     logger.error(
@@ -255,6 +260,9 @@ class WSConnection(FLConnection):
                 logger.error(
                     "PartyRecvLoop : WebsocketException. Details: " + str(ex))
                 return False
+            except socket.gaierror as ex:
+                logger.error("PartyRecvLoop : Error connecting to " + uri + ". Exception is " + str(ex))
+                return False
             except Exception as ex:
                 logger.error("PartyRecvLoop : Exception is " + str(ex))
                 return False
@@ -439,7 +447,7 @@ class WSSender(FLSender):
             response = party_rbuffer.popleft()
         except IndexError:
             logger.debug("[WSSender] No message response received, after attempt to send message")
-    
+
         pRecvEvt.clear()
         response_message = None
         if response is not None:
