@@ -8,13 +8,15 @@ irrespective of what has been deposited with the U.S. Copyright Office.
 """
 import logging
 import time
+import json
 import numpy as np
 import tensorflow as tf
-
+import inspect
 # if tf.__version__ != "2.1.0":
 # raise ImportError("This function requires TensorFlow v2.1.0.")
 
 from ibmfl.util import config
+from ibmfl.util import fl_metrics
 from ibmfl.model.fl_model import FLModel
 from ibmfl.model.model_update import ModelUpdate
 from ibmfl.exceptions import FLException, LocalTrainingException, ModelException
@@ -55,7 +57,7 @@ class TensorFlowFLModel(FLModel):
             if not issubclass(type(tf_model), tf.keras.Model):
                 raise ValueError('Compiled TensorFlow model needs to be '
                                  'provided of type `tensorflow.keras.models`.'
-                                 ' Type provided' + str(type(tf_model)))
+                                 ' Type provided: ' + str(type(tf_model)))
 
             if self.use_gpu_for_training and self.num_gpus >= 1:
                 strategy = tf.distribute.MirroredStrategy()
@@ -63,11 +65,13 @@ class TensorFlowFLModel(FLModel):
                     self.model = tf_model
             else:
                 self.model = tf_model
-
+        self.model_type = 'TensorFlow-2.1.0'
         # Default values for local training
         self.batch_size = 128
         self.epochs = 1
         self.steps_per_epoch = 100
+        self.is_classification = True if not (model_spec and model_spec.get(
+            'is_classification')) else model_spec.get('is_classification')
 
     def fit_model(self, train_data, fit_params=None, **kwargs):
         """
@@ -85,38 +89,22 @@ class TensorFlowFLModel(FLModel):
         :type fit_params: `dict`
         :return: None
         """
-        # Initialized with default values
-        batch_size = self.batch_size
-        epochs = self.epochs
-        steps_per_epoch = self.steps_per_epoch
 
-        # extract hyperparams from fit_param
-        if fit_params and ('hyperparams' in fit_params):
-            hyperparams = fit_params['hyperparams']
-            if hyperparams is not None and hyperparams.get('local') is not None and hyperparams.get('local').get('training') is not None :
-                training_hp = hyperparams['local']['training']
+        hyperparams = fit_params.get('hyperparams', {}) or {
+        } if fit_params else {}
+        local_hp = hyperparams.get('local', {}) or {}
+        training_hp = local_hp.get('training', {}) or {}
 
-                if 'batch_size' in training_hp:
-                    batch_size = training_hp['batch_size']
-                else:
-                    # In this case, use default values.
-                    logger.info('Using default hyperparameters: '
-                                ' batch_size:' + str(self.batch_size))
-                if 'epochs' in training_hp:
-                    epochs = training_hp['epochs']
-                else:
-                    # In this case, use default values.
-                    logger.info('Using default hyperparameters: '
-                                ' epochs:' + str(self.epochs))
+        # Initialized with default values if not in training_hp
+        batch_size = training_hp.get('batch_size', self.batch_size)
+        epochs = training_hp.get('epochs', self.epochs)
+        steps_per_epoch = training_hp.get(
+            'steps_per_epoch', self.steps_per_epoch)
 
-                if 'steps_per_epoch' in training_hp:
-                    steps_per_epoch = training_hp.get('steps_per_epoch')
+        logger.info('Training hps for this round => '
+                    'batch_size: {}, epochs {}, steps_per_epoch {}'
+                    .format(batch_size, epochs, steps_per_epoch))
 
-            else :
-                # In this case, use default values.
-                logger.info('Using default hyperparameters: '
-                            'epochs:' + str(self.epochs) +
-                            ' batch_size:' + str(self.batch_size))
         try:
             if type(train_data) is tuple and type(train_data[0]) is np.ndarray:
                 # Extract x_train and y_train, by default,
@@ -140,10 +128,10 @@ class TensorFlowFLModel(FLModel):
         """
         Update TensorFlow model with provided model_update, where model_update \
         should be generated according to \
-        `TensorFlowFLModel.get_model_update()`. 
+        `TensorFlowFLModel.get_model_update()`.
 
         :param model_update: `ModelUpdate` object that contains the weights \
-        that will be used to update the model. 
+        that will be used to update the model.
         :type model_update: `ModelUpdate`
         :return: None
         """
@@ -153,7 +141,7 @@ class TensorFlowFLModel(FLModel):
         else:
             raise LocalTrainingException('Provided model_update should be of '
                                          'type ModelUpdate. '
-                                         'Instead they are:' +
+                                         'Instead they are: ' +
                                          str(type(model_update)))
 
     def get_model_update(self):
@@ -181,42 +169,105 @@ class TensorFlowFLModel(FLModel):
         """
         return self.model.predict(x, **kwargs)
 
-    def evaluate(self, test_dataset, batch_size=128, **kwargs):
+    def evaluate(self, test_dataset, **kwargs):
         """
         Evaluates the model given testing data.
 
         :param test_dataset: Testing data, a tuple given in the form \
-        (x_test, y_test) or a datagenerator of type `keras.utils.Sequence`,
+        (x_test, y_test) or a datagenerator of type `keras.utils.Sequence`, \
         `keras.preprocessing.image.ImageDataGenerator`
-        :type test_dataset: `np.ndarray` or `keras.utils.Sequence`, \
-        `keras.preprocessing.image.ImageDataGenerator`
-        :param batch_size: batch_size: Size of batches.
-        :type batch_size: `int`
+        :type test_dataset: `np.ndarray`
         :param kwargs: Dictionary of metrics available for the model
         :type kwargs: `dict`
+        :return: metrics
+        :rtype: `dict`
         """
+
         if type(test_dataset) is tuple:
             x_test = test_dataset[0]
             y_test = test_dataset[1]
 
-            metrics = self.model.evaluate(x_test, y_test,
-                                          batch_size=batch_size,
-                                          **kwargs)
-        else:
-            metrics = self.model.evaluate(test_dataset, **kwargs)
+            return self.evaluate_model(x_test, y_test, **kwargs)
 
+        else:
+            return self.evaluate_generator_model(
+                test_dataset, **kwargs)
+
+    def evaluate_model(self, x, y, batch_size=128, **kwargs):
+        """
+        Evaluates the model given x and y.
+
+        :param x: Samples with shape as expected by the model.
+        :type x: `np.ndarray`
+        :param y: Corresponding labels to x
+        :type y: `np.ndarray`
+        :param batch_size: Size of batches.
+        :type batch_size: `int`
+        :param kwargs: Dictionary of metrics available for the model
+        :type kwargs: `dict`
+        :return: metrics
+        :rtype: `dict`
+        """
+
+        metrics = self.model.evaluate(
+            x, y, batch_size=batch_size, **kwargs)
         names = self.model.metrics_names
         dict_metrics = {}
-
+        additional_metrics = {}
         if type(metrics) == list:
             for metric, name in zip(metrics, names):
-                metric = metric.item()
+                # metric = metric.item()
                 if name == 'accuracy':
                     dict_metrics['acc'] = round(metric, 2)
-                
                 dict_metrics[name] = metric
         else:
             dict_metrics[names[0]] = metrics
+
+        y_pred = self.predict(x, batch_size=batch_size)
+        if self.is_classification:
+            additional_metrics = fl_metrics.get_eval_metrics_for_classificaton(
+                y, y_pred)
+        else:
+            additional_metrics = fl_metrics.get_eval_metrics_for_regression(
+                y, y_pred)
+
+        logger.info(additional_metrics)
+        dict_metrics = {**dict_metrics, **additional_metrics}
+        logger.info(dict_metrics)
+
+        return dict_metrics
+
+    def evaluate_generator_model(self, test_generator, **kwargs):
+        """
+        Evaluates the model based on the provided data generator.
+
+        :param test_generator: Testing datagenerator of type \
+        `keras.utils.Sequence`, or \
+        `keras.preprocessing.image.ImageDataGenerator`.
+        :type test_generator: `ImageDataGenerator` or `keras.utils.Sequence`
+        :return: metrics
+        :rtype: `dict`
+        """
+
+        steps = self.steps_per_epoch
+        if steps in kwargs:
+            steps = kwargs.get('steps')
+
+        metrics = self.model.evaluate_generator(
+            test_generator, steps=steps)
+        names = self.model.metrics_names
+        dict_metrics = {}
+        additional_metrics = {}
+
+        if type(metrics) == list:
+            for metric, name in zip(metrics, names):
+                # metric = metric.item()
+                if name == 'accuracy':
+                    dict_metrics['acc'] = round(metric, 2)
+                dict_metrics[name] = metric
+        else:
+            dict_metrics[names[0]] = metrics
+
         return dict_metrics
 
     @staticmethod
@@ -230,7 +281,8 @@ class TensorFlowFLModel(FLModel):
         :rtype: `tf.keras.models.Model`
         """
         try:
-            model = tf.keras.models.load_model(file_name)
+            model = tf.keras.models.load_model(
+                file_name, custom_objects=custom_objects)
         except Exception as ex:
             logger.exception(str(ex))
             logger.error(
@@ -247,7 +299,8 @@ class TensorFlowFLModel(FLModel):
         :rtype `string`
         """
         if filename is None:
-            filename = '.'
+            file = self.model_name if self.model_name else self.model_type
+            filename = '{}_{}'.format(file, time.time())
 
         full_path = super().get_model_absolute_path(filename)
         self.model.save(full_path)
@@ -255,7 +308,7 @@ class TensorFlowFLModel(FLModel):
         return filename
 
     @staticmethod
-    def model_from_json_via_tf_keras(json_file_name):
+    def model_from_json_via_tf_keras(json_file_name, custom_objects={}):
         """
         Loads a model architecture from disk via tf.keras \
         given the specified json file name.
@@ -263,6 +316,8 @@ class TensorFlowFLModel(FLModel):
         :param json_file_name: Name of the file that contains \
         the model architecture to be loaded.
         :type json_file_name: `str`
+        :param custom_objects: Dictionary of custom objects required for loading arch
+        :type custom_objects: `dict`
         :return: tf.keras model with only model architecture loaded to memory
         :rtype: `tf.keras.models.Model`
         """
@@ -271,7 +326,8 @@ class TensorFlowFLModel(FLModel):
         f = json_file.read()
         json_file.close()
         try:
-            model = tf.keras.models.model_from_json(f)
+            model = tf.keras.models.model_from_json(
+                f, custom_objects=custom_objects)
         except Exception as ex:
             logger.error(
                 'Loading model via tf.keras.models.model_from_json failed! ')
@@ -283,16 +339,26 @@ class TensorFlowFLModel(FLModel):
         Loads model from provided model_spec, where model_spec is a `dict` \
         that contains the following items: \
             'model_definition': the path where the tf model is stored, \
-                usually in a `SavedModel` format. 
+                usually in a `SavedModel` format.
         :return: model
         :rtype: `keras.models.Model`
         """
+        custom_objects = {}
+        if 'custom_objects' in model_spec:
+
+            custom_objects_config = model_spec['custom_objects']
+            for custom_object in custom_objects_config:
+                key = custom_object['key']
+                value = custom_object['value']
+                path = custom_object['path']
+                custom_objects[key] = config.get_attr_from_path(
+                    path, value)
+
         if 'model_definition' in model_spec:
             try:
                 model_file = model_spec['model_definition']
                 model_absolute_path = config.get_absolute_path(model_file)
 
-                custom_objects = {}
                 if self.use_gpu_for_training:
                     strategy = tf.distribute.MirroredStrategy()
                     with strategy.scope():
@@ -306,50 +372,71 @@ class TensorFlowFLModel(FLModel):
                 logger.exception(str(ex))
                 raise FLException('Failed to load TensorFlow model!')
         else:
-            # Load architecture from json file
-            try:
-                model = TensorFlowFLModel.model_from_json_via_tf_keras(
-                    model_spec['model_architecture'])
 
-                if model is None:
-                    logger.error(
-                        'An acceptable compiled model should be of type '
-                        'tensorflow.keras.models!')
-            except Exception as ex:
-                logger.error(str(ex))
-                raise FLException(
-                    'Unable to load the provided uncompiled model!')
+            if self.use_gpu_for_training:
+                strategy = tf.distribute.MirroredStrategy()
+                model = self.load_model_from_architecture(
+                    model_spec, custom_objects)
+
+            else:
+                model = self.load_model_from_architecture(
+                    model_spec, custom_objects)
+
+        return model
+
+    def load_model_from_architecture(self, model_spec, custom_objects):
+        """
+        Loads model from provided model_spec, where model_spec is a `dict` \
+        that contains the following items: \
+            'model_architecture': the path where the tf model is stored, \
+                usually in a `SavedModel` format. \
+            'model_weights': the path to where the tf model weights are saved \
+            'compile_model_options': attributes used to compile model.
+        :param model_spec: Disctionary of spec provided by the user
+        :type model_spec: `dict`
+        :param custom_objects: Dictionary of custom objects required for loading arch
+        :type custom_objects: `dict`
+        :return: model
+        :rtype: `keras.models.Model`
+        """
+
+        try:
+            model = TensorFlowFLModel.model_from_json_via_tf_keras(
+                model_spec['model_architecture'], custom_objects=custom_objects)
+
+            if model is None:
+                logger.error('An acceptable compiled model should be of type '
+                             'tensorflow.keras.models!')
+        except Exception as ex:
+            logger.error(str(ex))
+            raise FLException('Unable to load the provided uncompiled model!')
 
             # Load weights from provided path
-            if 'model_weights' in model_spec:
-                model.load_weights(model_spec['model_weights'])
+        if 'model_weights' in model_spec:
+            model.load_weights(model_spec['model_weights'])
 
-            if 'compile_model_options' in model_spec:
-                # Load compile options:
+        if 'compile_model_options' in model_spec:
+            # Load compile options:
+            try:
                 compiled_options = model_spec['compile_model_options']
-                optimizer = compiled_options.get('optimizer')
-                loss = compiled_options.get('loss')
-                metrics = compiled_options.get('metrics')
+                optimizer = self.get_custom_attribute(
+                    compiled_options.get('optimizer'))
+                loss = self.get_custom_attribute(compiled_options.get('loss'))
+                metrics = self.get_custom_attribute(
+                    compiled_options.get('metrics'))
                 metrics = [metrics] if not isinstance(
                     metrics, list) else metrics
-                try:
-                    if self.use_gpu_for_training:
-                        strategy = tf.distribute.MirroredStrategy()
-                        with strategy.scope():
-                            model.compile(optimizer=optimizer,
-                                          loss=loss,
-                                          metrics=metrics)
-                    else:
-                        model.compile(optimizer=optimizer,
-                                      loss=loss,
-                                      metrics=metrics)
-                except Exception as ex:
-                    logger.exception(str(ex))
-                    logger.exception(
-                        'Failed to compiled the TensorFlow.keras model.')
-            else:
-                raise ModelException(
-                    'Failed to compile keras model, no compile options provided.')
+                model.compile(optimizer=optimizer,
+                              loss=loss,
+                              metrics=metrics)
+            except Exception as ex:
+                logger.exception(str(ex))
+                logger.exception(
+                    'Failed to compiled the TensorFlow.keras model.')
+        else:
+            raise ModelException('Failed to compile keras model, '
+                                 'no compile options provided.')
+
         return model
 
     def get_gradient(self, train_data):
@@ -377,6 +464,77 @@ class TensorFlowFLModel(FLModel):
         gradients = tape.gradient(loss, self.model.trainable_variables)
         return gradients
 
+    def expand_model_by_layer_name(self, new_dimension, layer_name="dense"):
+        """
+        Expand the current Keras model with provided dimension of
+        the hidden layers or model weights.
+        This method by default expands the dense layer of
+        the current neural network.
+        It can be extends to expand other layers specified by `layer_name`,
+        for example, it can be use to increase the number of CNN filters or
+        increase the hidden layer size inside LSTM.
+
+        :param new_dimension: New number of dimensions for \
+        the fully connected layers
+        :type new_dimension: `list`
+        :param layer_name: layer's name to be expanded
+        :type layer_name: `str`
+        :return: None
+        """
+        if new_dimension is None:
+            raise FLException('No information is provided for '
+                              'the new expanded model. '
+                              'Please provide the new dimension of '
+                              'the resulting expanded model.')
+        try:
+            model_config = json.loads(self.model.to_json())
+        except NotImplementedError:
+            raise ModelException(
+                "Please construct the model config for models in "
+                "`SavedModel` format. "
+                "Details about how to construct the model config can be found"
+                " in TensorFlowFLModel tutorials.")
+        except Exception as ex:
+            logger.exception(str(ex))
+            raise FLException("Error occurred during extracting "
+                              "the model architecture.")
+        i = 0
+
+        for layer in model_config['config']['layers']:
+            # find the specified layers
+            if 'class_name' in layer and \
+                    layer['class_name'].strip().lower() == layer_name:
+                layer['config']['units'] = new_dimension[i]
+                i += 1
+
+        custom_obj = {
+            self.model.__class__.__name__: self.model.__class__
+        }
+
+        try:
+            new_model = tf.keras.models.model_from_json(
+                json.dumps(model_config), custom_objects=custom_obj)
+        except Exception as ex:
+            logger.exception(str(ex))
+            raise FLException("Error occurred during loading model from "
+                              "the new config.")
+
+        metrics = self.model.metrics_names
+        if 'loss' in metrics:
+            metrics.remove('loss')
+        if not self.use_gpu_for_training or self.num_gpus == 1:
+            new_model.compile(optimizer=self.model.optimizer,
+                              loss=self.model.loss,
+                              metrics=metrics)
+        else:
+            strategy = tf.distribute.MirroredStrategy()
+            with strategy.scope():
+                new_model.compile(optimizer=self.model.optimizer,
+                                  loss=self.model.loss,
+                                  metrics=metrics)
+
+        self.model = new_model
+
     def is_fitted(self):
         """
         Return a boolean value indicating if the model is fitted or not. \
@@ -391,3 +549,65 @@ class TensorFlowFLModel(FLModel):
         except Exception:
             return False
         return True
+
+    def get_loss(self, dataset):
+        """
+        Return the resulting loss computed based on the provided dataset.
+
+        :param dataset: Provided dataset, a tuple given in the form \
+        (x_test, y_test) or a datagenerator of type `keras.utils.Sequence`, \
+        `keras.preprocessing.image.ImageDataGenerator`.
+        :type dataset: `np.ndarray`
+        :return: The resulting loss.
+        :rtype: `float`
+        """
+        if 'loss' not in self.model.metrics_names:
+            self.model.metrics_names.append('loss')
+        res = self.evaluate(dataset)
+
+        if 'loss' in res:
+            loss = round(res['loss'], 2)
+            return loss
+        else:
+            raise FLException(
+                "Loss is not listed in the model's metrics_names.")
+
+    def get_custom_attribute(self, attr):
+        """
+        Load compiled options which are provided as config.
+        :param attr: Attribute config provided in config
+        :type attr: dict or key
+        :return: Attribute loaded and returned back for compilation
+        :rtype: `str` or python attr
+
+        """
+        if attr is None:
+            raise ModelException("Invalid Model config exception")
+
+        if isinstance(attr, dict):
+            try:
+
+                value = attr.get('value')
+                path = attr.get('path')
+                args = attr.get('args') if 'args' in attr else {}
+                attribute = config.get_attr_from_path(
+                    path, value)
+
+            except Exception as ex:
+                logger.error(
+                    "Error occurred while loading the custom attribute!")
+                logger.error("Custom attribute : " + attr)
+                logger.error()
+
+            logger.debug(type(attribute))
+
+            if inspect.isclass(attribute):
+                return attribute(**args)
+            else:
+                return attribute
+
+        else:
+            return attr
+
+
+        
